cumulusci.tasks.metadata.tests package
======================================

Submodules
----------


.. automodule:: cumulusci.tasks.metadata.tests.test_ee_src
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.metadata.tests.test_managed_src
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.metadata.tests.test_modify
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.metadata.tests.test_package
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.tasks.metadata.tests
   :members:
   :undoc-members:
   :show-inheritance:
